@@ -60,7 +60,7 @@ class InternetSpeedMonitorWebthing(Thing):
         self.downloadspeed = Value(0)
         self.add_property(
             Property(self,
-                     'downloadspeed',
+                     'download speed',
                      self.downloadspeed,
                      metadata={
                          '@type': 'LevelProperty',
@@ -74,7 +74,7 @@ class InternetSpeedMonitorWebthing(Thing):
         self.uploadspeed = Value(0)
         self.add_property(
             Property(self,
-                     'uploadspeed',
+                     'upload speed',
                      self.uploadspeed,
                      metadata={
                          '@type': 'LevelProperty',
@@ -88,7 +88,7 @@ class InternetSpeedMonitorWebthing(Thing):
         self.ping_time = Value(0)
         self.add_property(
             Property(self,
-                     'ping',
+                     'ping time',
                      self.ping_time,
                      metadata={
                          '@type': 'LevelProperty',
@@ -102,7 +102,7 @@ class InternetSpeedMonitorWebthing(Thing):
         self.testperiod = Value(speedtest_period)
         self.add_property(
             Property(self,
-                     'test_period',
+                     'test period',
                      self.testperiod,
                      metadata={
                          '@type': 'LevelProperty',
@@ -116,39 +116,36 @@ class InternetSpeedMonitorWebthing(Thing):
         self.testdate = Value("")
         self.add_property(
             Property(self,
-                     'testdate',
+                     'last executed test',
                      self.testdate,
                      metadata={
-                         '@type': 'Name',
-                         'title': 'The test date',
+                         'title': 'date of the last test',
                          'type': 'string',
-                         'description': 'The last speedtest execution date',
+                         'description': 'The date of the last successfully executed test',
                          'readOnly': True,
                      }))
 
         self.testserver = Value("")
         self.add_property(
             Property(self,
-                     'speedtest_server',
+                     'speedtest servername',
                      self.testserver,
                      metadata={
-                         '@type': 'Name',
-                         'title': 'The speedtest server',
+                         'title': 'speedtest servername',
                          'type': 'string',
-                         'description': 'The server which has been connected to perform the speedtest',
+                         'description': 'The speedtest server which has been connected to perform the speedtest',
                          'readOnly': True,
                      }))
 
         self.resulturi = Value("")
         self.add_property(
             Property(self,
-                     'speedtest_report_uri',
+                     'speedtest result uri',
                      self.resulturi,
                      metadata={
-                         '@type': 'Name',
-                         'title': 'The speedtest report uri',
+                         'title': 'The speedtest result uri',
                          'type': 'string',
-                         'description': 'The speedtest report uri',
+                         'description': 'The speedtest result report uri',
                          'readOnly': True,
                      }))
 
